<?php

if( ! defined( 'ABSPATH' ) ) exit(); // Exit if accessed directly

class PA_admin_settings {
    
    public $pa_elements_keys = ['premium-banner', 'premium-blog','premium-carousel', 'premium-countdown','premium-counter','premium-dual-header','premium-fancytext','premium-image-separator','premium-maps','premium-modalbox','premium-person','premium-progressbar','premium-testimonials','premium-title','premium-videobox'];
    
    private $pa_default_settings;
    
    private $pa_settings;
    
    private $pa_get_settings;

    public function __construct() {
        add_action( 'admin_menu', array( $this,'pa_admin_menu') );
        add_action('init', array( $this, 'pa_admin_page_scripts' ) );
        add_action( 'wp_ajax_save_settings_with_ajax', array( $this, 'pa_save_settings_with_ajax' ) );
    }

    public function pa_admin_page_scripts () {
        if( isset( $_GET['page'] ) && $_GET['page'] == 'pa-settings-page' ) {
        wp_enqueue_style( 'premium_addons_elementor-css', plugins_url( '/', __FILE__ ).'assets/admin.css' );
        wp_enqueue_style('font-awesome', plugins_url( '/' , __FILE__ ).'assets/font-awesome/css/font-awesome.min.css');
        wp_enqueue_style( 'premium_addons-sweetalert2-css', plugins_url( '/', __FILE__ ).'assets/js/sweetalert2/css/sweetalert2.min.css' );
        wp_enqueue_script('pa-addons-elementor-admin-js', plugins_url( '/' , __FILE__ ).'assets/admin.js' , array('jquery','jquery-ui-tabs'), '1.0' , true );
        wp_enqueue_script( 'premium_addons_sweet-js', plugins_url( '/', __FILE__ ).'assets/js/sweetalert2/js/core.js', array( 'jquery' ), '1.0', true );
			wp_enqueue_script( 'premium_addons_sweetalert2-js', plugins_url( '/', __FILE__ ).'assets/js/sweetalert2/js/sweetalert2.min.js', array( 'jquery', 'premium_addons_sweet-js' ), '1.0', true );
    }
    }

    public function pa_admin_menu() {
        add_menu_page( 'Premium Addons for Elementor', 'Premium Addons for Elementor', 'manage_options', 'pa-settings-page', array( $this , 'pa_admin_page' ), 'dashicons-star-empty', 100  );
    }

    public function pa_admin_page(){
        $js_info = array(
			'ajaxurl' => admin_url( 'admin-ajax.php' )
		);
		wp_localize_script( 'pa-addons-elementor-admin-js', 'settings', $js_info );

	   $this->pa_default_settings = array_fill_keys( $this->pa_elements_keys, true );
	   $this->pa_get_settings = get_option( 'pa_save_settings', $this->pa_default_settings );
	   $pa_new_settings = array_diff_key( $this->pa_default_settings, $this->pa_get_settings );
	   if( ! empty( $pa_new_settings ) ) {
	   	$pa_updated_settings = array_merge( $this->pa_get_settings, $pa_new_settings );
	   	update_option( 'pa_save_settings', $pa_updated_settings );
	   }
	   $this->pa_get_settings = get_option( 'pa_save_settings', $this->pa_default_settings );
	?>
	<div class="wrap">
        <div class="response-wrap"></div>
        <form action="" method="POST" id="pa-settings" name="pa-settings">
            <div class="pa-header-wrapper">
                <div class="pa-title-left">
                    <h1 class="pa-title"><?php echo esc_html__('Premium Addons for Elementor', 'premium_elementor'); ?></h1>
                </div>
                <div class="pa-title-right">
                    <input type="submit" value="Save Settings" class="button pa-btn pa-save-button">
                </div>
            </div>
            <div class="pa-settings">
            <h1>PREMIUM ADDONS ELEMENTS</h1>
                <div id="elements" class="pa-settings-tab">
                    <p class="pa-elements-notice">Choosing only the elements which you need will improve your site loading speed</p>
                    <div class="pa-row">
                        <table class="pa-elements-table">
                            <tr>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-banner" name="premium-banner" <?php checked(1, $this->pa_get_settings['premium-banner'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Banner', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Banner', 'premium_elementor');?></p>
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-blog" name="premium-blog" <?php checked(1, $this->pa_get_settings['premium-blog'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Blog', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Blog', 'premium_elementor');?></p>
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-carousel" name="premium-carousel" <?php checked(1, $this->pa_get_settings['premium-carousel'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Carousel', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Carousel', 'premium_elementor');?></p>
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-countdown" name="premium-countdown" <?php checked(1, $this->pa_get_settings['premium-countdown'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Countdown', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Countdown', 'premium_elementor');?></p>
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-counter" name="premium-counter" <?php checked(1, $this->pa_get_settings['premium-counter'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Counter', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Counter', 'premium_elementor');?></p>
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-dual-header" name="premium-dual-header" <?php checked(1, $this->pa_get_settings['premium-dual-header'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Dual Header', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Dual Header', 'premium_elementor');?></p>                                       
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-fancytext" name="premium-fancytext" <?php checked(1, $this->pa_get_settings['premium-fancytext'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Fancy Text', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Fancy Text', 'premium_elementor');?></p>                                      
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-image-separator" name="premium-image-separator" <?php checked(1, $this->pa_get_settings['premium-image-separator'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Image Separator', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Image Separator', 'premium_elementor');?></p>
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-maps" name="premium-maps" <?php checked(1, $this->pa_get_settings['premium-maps'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Maps', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Maps', 'premium_elementor');?></p>
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-modalbox" name="premium-modalbox" <?php checked(1, $this->pa_get_settings['premium-modalbox'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Modal Box', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Modal Box', 'premium_elementor');?></p> 
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-person" name="premium-person" <?php checked(1, $this->pa_get_settings['premium-person'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Person', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Person', 'premium_elementor');?></p>                                       
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-progressbar" name="premium-progressbar" <?php checked(1, $this->pa_get_settings['premium-progressbar'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Progress Bar', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Progress Bar', 'premium_elementor');?></p>
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-testimonials" name="premium-testimonials" <?php checked(1, $this->pa_get_settings['premium-testimonials'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Testimonials', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Testimonials', 'premium_elementor');?></p>
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-title" name="premium-title" <?php checked(1, $this->pa_get_settings['premium-title'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Title', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Title', 'premium_elementor');?></p>
                                    </div>
                                </td>
                                <td>
                                    <div class="pa-element-wrapper">
                                        <label class="switch">
                                            <input type="checkbox" id="premium-videobox" name="premium-videobox" <?php checked(1, $this->pa_get_settings['premium-videobox'], true) ?>>
                                            <span class="slider round"></span>
                                        </label>
                                        <p class="pa-element-name"><?php echo esc_html__('Premium Video Box', 'premium_elementor'); ?></p>
                                        <p class="pa-element-desc"><?php echo esc_html__('Enable/Disable Premium Video Box', 'premium_elementor');?></p>
                                    </div>
                                </td>
                            </tr>
                        </table>
                        <input type="submit" value="Save Settings" class="button pa-btn pa-save-button">
                    </div>
                </div>
            </div>
            </form>
        </div>
	<?php
}

    public function pa_save_settings_with_ajax() {

            if( isset( $_POST['fields'] ) ) {
                parse_str( $_POST['fields'], $settings );
            }else {
                return;
            }

            $this->pa_settings = array(
                'premium-banner'            => intval( $settings['premium-banner'] ? 1 : 0 ),
                'premium-blog'              => intval( $settings['premium-blog'] ? 1 : 0 ),
                'premium-carousel'          => intval( $settings['premium-carousel'] ? 1 : 0 ),
                'premium-countdown'         => intval( $settings['premium-countdown'] ? 1 : 0 ),
                'premium-counter'           => intval( $settings['premium-counter'] ? 1 : 0 ),
                'premium-dual-header'       => intval( $settings['premium-dual-header'] ? 1 : 0 ),
                'premium-fancytext'         => intval( $settings['premium-fancytext'] ? 1 : 0 ),
                'premium-image-separator'   => intval( $settings['premium-image-separator'] ? 1 : 0 ),
                'premium-maps'              => intval( $settings['premium-maps'] ? 1 : 0 ),
                'premium-modalbox' 			=> intval( $settings['premium-modalbox'] ? 1 : 0 ),
                'premium-person' 			=> intval( $settings['premium-person'] ? 1 : 0 ),
                'premium-progressbar' 		=> intval( $settings['premium-progressbar'] ? 1 : 0 ),
                'premium-testimonials' 		=> intval( $settings['premium-testimonials'] ? 1 : 0 ),
                'premium-title'             => intval( $settings['premium-title'] ? 1 : 0 ),
                'premium-videobox'          => intval( $settings['premium-videobox'] ? 1 : 0 ),
                'wisdom_registered_setting' => 1,
            );
            update_option( 'pa_save_settings', $this->pa_settings );
            return true;
            die();


        }
}


new PA_admin_settings();
