<?php 
/*
Plugin Name: Premium Addons for Elementor
Description: This Plugin Includes Elementor Page Builder’s Premium Addon Elements.
Plugin URI: https://premiumaddons.com
Version: 1.04
Author: Leap13
Author URI: http://leap13.com/
Text Domain: premium-addons-leap13
License: GNU General Public License v3.0
*/


/**
* Checking the set ups and the environment
*/

if( !function_exists('add_action') ) {
	die('WordPress not Installed'); // if WordPress not installed kill the page.
}

if( !defined( 'ABSPATH' ) ) exit; // No access of directly access

define( 'PREMIUM_ADDONS_URL', plugins_url('/', __FILE__ ) );
define( 'PREMIUM_ADDONS_PATH', plugin_dir_path( __FILE__ ) );

	/**
	* Translating the plugins and load some 
	* assets
	*/
	add_action( 'plugins_loaded', 'premium_addons_elementor_setup');
	function premium_addons_elementor_setup() {
		// Loading .mo and.po file from the lang folder
		load_plugin_textdomain( 'premium_elementor', false, dirname( plugin_basename( __FILE__ ) ) . '/lang' );


		// Requires Elmentor Page builder & activation

		//if( file_exists( PREMIUM_ADDONS_PATH . 'admin/activation/elementor-activation.php' ) ) {
		//	require_once( PREMIUM_ADDONS_PATH . 'admin/activation/elementor-activation.php' );
		//}

		// load the template tags
		if( file_exists( PREMIUM_ADDONS_PATH.'elementor-helper.php' ) ) {
			require_once( PREMIUM_ADDONS_PATH.'elementor-helper.php' );
		}
        
        if( file_exists( PREMIUM_ADDONS_PATH.'admin/settings-page.php' ) ) {
            require_once( PREMIUM_ADDONS_PATH.'admin/settings-page.php' );
		}
        

		/*
		* Instantiate the premium Addons for the elementor page builder
		* Included 1. 'premium_addons_widget_register()' for the main method for initaite addons
		*          2. 'premium_addons_widgets_area()'  creating the widgets
		*          3. 'initiate_elementor_addons()' creating the category of the widgets
		*/
		
		new premium_Addon_Elementor();
	}
    // CSS THAT DISPLAYS ON EDITOR PANEL
    add_action( 'elementor/editor/before_enqueue_scripts', function() {
       wp_register_style( 'premium-elements-progression-admin-styles', PREMIUM_ADDONS_URL . 'admin/assets/pa-elements-font/css/pa-elements.css' );
       wp_enqueue_style( 'premium-elements-progression-admin-styles' );

    } );

	class premium_Addon_Elementor {

		/**
		* Load all the hooks here
		* @since 1.0
		*/
		public function __construct() {
         add_action( 'elementor/init', array( $this, 'initiate_elementor_addons' ) );
			add_action( 'elementor/widgets/widgets_registered', array( $this, 'premium_addons_widget_register') );
			add_action( 'wp_enqueue_scripts', array( $this, 'premium_addons_required_assets') );
			add_action( 'elementor/frontend/after_register_styles', array( $this, 'frontendafter_style') );
			add_action( 'elementor/preview/enqueue_styles', array( $this, 'elementor_preview_styles' ) );
			add_filter( 'plugin_row_meta', [ $this, 'plugin_row_meta' ], 10, 2 );
		}
        

		/**
		* Load all frontend assets file such as stylesheet & javascript files
		* @since 1.0
		*/
		public function premium_addons_required_assets() {
            $check_component_active = get_option( 'pa_save_settings' );
            wp_enqueue_style( 'fontAwesome', 'https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css', array(), '4.7.0', 'all' );
            wp_enqueue_style( 'premium-addons-css', PREMIUM_ADDONS_URL . 'assets/css/premium-addons.css', array(), '1.0', 'all' ); 
            
            wp_enqueue_style( 'animate-css', PREMIUM_ADDONS_URL . 'assets/css/animate.css', array(), '1.6.0', 'all' );

            wp_enqueue_script('premium-addons-js', PREMIUM_ADDONS_URL .'assets/js/premium-addons.js',  array( 'jquery' ), '2.1.0', true );

            if( $check_component_active['premium-carousel'] ) {
                wp_enqueue_script( 'slick-carousel-js', PREMIUM_ADDONS_URL .'assets/js/lib/slickmin.js', array( 'jquery' ), '1.6.0', true );
            }
            if( $check_component_active['premium-countdown'] ) {
                wp_enqueue_script( 'count-down-timer-js', PREMIUM_ADDONS_URL .'assets/js/lib/jquerycountdown.js', array( 'jquery' ), '2.1.0', true );
            }        
            if( $check_component_active['premium-counter'] ) {
                wp_enqueue_script( 'counter-up-js', PREMIUM_ADDONS_URL .'assets/js/lib/countUpmin.js', array( 'jquery' ), '2.1.0', true );
            }
            if( $check_component_active['premium-fancytext'] ) {
                wp_enqueue_script('vticker-js', PREMIUM_ADDONS_URL .'assets/js/lib/Vticker.js',  array( 'jquery' ), '1.0', true);
                wp_enqueue_script('typed-js', PREMIUM_ADDONS_URL .'assets/js/lib/typedmin.js',  array( 'jquery' ), '1.0', true);
            }        
            if( $check_component_active['premium-maps'] ) {
                wp_enqueue_script('google-maps', 'http://maps.google.com/maps/api/js?sensor=false');
                wp_enqueue_script('gomap', PREMIUM_ADDONS_URL. 'assets/js/lib/gomap.js',  array( 'jquery' ), '1.0', true);
            }
            }

		/**
		* Deregister for the default animations.min.css file
		* @since 1.0
		*/
		public function frontendafter_style() {
			wp_deregister_style( 'elementor-animations' );
		}
        
        

		// CSS THAT DISPLAYS ONLY WHEN EDITOR IS OPEN ON IFRAME
		public function elementor_preview_styles() {
		 	wp_enqueue_style( 'elementor-edit-preview', PREMIUM_ADDONS_URL .'assets/css/elementor-preview-style.css' );
		}

		public function premium_addons_widget_register() {
			$this->initiate_elementor_addons();
			$this->premium_addons_widgets_area();
		}

		private function premium_addons_widgets_area() {
            $pa_elements_keys = ['premium-banner', 'premium-blog','premium-carousel', 'premium-countdown','premium-counter','premium-dual-header','premium-fancytext','premium-image-separator','premium-maps','premium-modalbox','premium-person','premium-progressbar','premium-testimonials','premium-title','premium-videobox'];
            
            $pa_default_settings = array_fill_keys( $pa_elements_keys, true );

            $check_component_active = get_option( 'pa_save_settings', $pa_default_settings );
            
            if( $check_component_active['premium-banner'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-banner.php' );
            }
            if( $check_component_active['premium-carousel'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-carousel.php' );
            }
			
            if( $check_component_active['premium-countdown'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-countdown.php' );
            }
			
            if( $check_component_active['premium-counter'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-counter.php' );
            }
            
            if( $check_component_active['premium-image-separator'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-imageseparator.php' );
            }
            
            if( $check_component_active['premium-modalbox'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-modalbox.php' );
            }
            if( $check_component_active['premium-progressbar'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-progressbar.php' );
            }
            
            if( $check_component_active['premium-testimonials'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-testimonials.php' );
            }
            
            if( $check_component_active['premium-title'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-title.php' );
            }
            
            if( $check_component_active['premium-fancytext'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-fancytext.php' );
            }
            
            if( $check_component_active['premium-videobox'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-videobox.php' );
            }
            
            if( $check_component_active['premium-blog'] ) {
                require_once( PREMIUM_ADDONS_PATH.'queries.php' );
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-blog.php' );
            }
            
            if( $check_component_active['premium-person'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-person.php' );
            }
            
            if( $check_component_active['premium-maps'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-maps.php' );
            }
            
            if( $check_component_active['premium-dual-header'] ) {
                require_once( PREMIUM_ADDONS_PATH. 'widgets/premium-dual-header.php' );
            }
            
		}

		public function initiate_elementor_addons() {
			Elementor\Plugin::instance()->elements_manager->add_category(
				'premium-elements',
				array(
					'title' => __( 'Premium Addons', 'premium_elementor' )
				),
				1
			);
		}	
			function plugin_row_meta( $plugin_meta, $plugin_file ) {
			$row_meta = [
				'docs' => '<a href="http://premiumaddons.com/" title="' . esc_attr( __( 'Visit Plugin Site', 'premium_elementor' ) ) . '" target="_blank">' . __( 'Visit Plugin Site', 'premium_elementor' ) . '</a>',
			];

			$plugin_meta = array_merge( $plugin_meta, $row_meta );
		

		return $plugin_meta;
	}
	}
	require_once('wp-updates-plugin.php');
new WPUpdatesPluginUpdater_1837( 'http://wp-updates.com/api/2/plugin', plugin_basename(__FILE__));
	/**
	 * @since 1.1.4
	 * @access public
	*/







