<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Premium_Blog_Widget extends Widget_Base
{
    protected $templateInstance;

    public function getTemplateInstance() {
        return $this->templateInstance = premium_Template_Tags::getInstance();
    }

    public function get_name() {
        return 'premium-addon-blog';
    }

    public function get_title() {
        return esc_html__('Premium Blog', 'premium_elementor');
    }

    public function get_icon() {
        return 'pa-pa-post';
    }

    public function get_categories() {
        return [ 'premium-elements' ];
    }

    // Adding the controls fields for the premium blog
    // This will controls the animation, colors and background, dimensions etc
    protected function _register_controls() {

        /* Start Content Section */
        $this->start_controls_section('premium_blog_general_settings',
                [
                    'label'         => esc_html__('General Settings', 'premium_elementor'),
                    ]
                );
        
        /*Hover Image Effect*/ 
        $this->add_control('premium_blog_hover_image_effect',
                [
                    'label'         => esc_html__('Hover Image Effect', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'options'       => [
                        'zoomin' => esc_html__('Zoom In', 'premium_elementor'),
                        'zoomout'=> esc_html__('Zoom Out', 'premium_elementor'),
                        'scale'  => esc_html__('Scale', 'premium_elementor'),
                        'gray'   => esc_html__('Grayscale', 'premium_elementor'),
                        'blur'   => esc_html__('Blur', 'premium_elementor'),
                    ],
                    'default'       => 'zoomin',
                    'label_block'   => true
                ]
                );
        
        /*Hover Image Effect*/ 
        $this->add_control('premium_blog_hover_color_effect',
                [
                    'label'         => esc_html__('Hover Color Effect', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'options'       => [
                        'none'     => esc_html__('None', 'premium_elementor'),
                        'framed'   => esc_html__('Framed', 'premium_elementor'),
                        'diagonal' => esc_html__('Diagonal', 'premium_elementor'),
                        'bordered' => esc_html__('Bordered', 'premium_elementor'),
                        'squares'  => esc_html__('Squares', 'premium_elementor'),
                    ],
                    'default'       => 'none',
                    'label_block'   => true
                ]
                );
        
        /*Bordered Effect Border Color*/
        $this->add_control('premium_blog_border_effect_color',
                [
                    'label'         => esc_html__('Plus Icon Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#1c1c1c',
                    'condition'     => [
                      'premium_blog_hover_color_effect'  => 'bordered',
                    ],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-bordered-border-container' => 'border-color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Post Format Icon*/
        $this->add_control('premium_blog_post_format_icon',
            [
                'label'             => esc_html__( 'Post Icon', 'essential-addons-elementor' ),
                'type'              => Controls_Manager::SWITCHER,
                'default'           => 'yes',
            ]
        );
        
        /*Categories Filter*/
        $this->add_control('premium_blog_categories',
            [
                'label'             => esc_html__( 'Categories', 'essential-addons-elementor' ),
                'type'              => Controls_Manager::SELECT2,
                'label_block'       => true,
                'multiple'          => true,
                'options'           => premium_addons_post_type_categories(),        
            ]
        );
        
        /*Excerpt*/ 
        $this->add_control('premium_blog_excerpt',
                [
                    'label'         => esc_html__('Excerpt', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                    ]
                );

        
        /*Excerpt Length*/
        $this->add_control('premium_blog_excerpt_length',
                [
                    'label'         => esc_html__('Excerpt Length', 'premium_elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => 55,
                    'label_block'   => true,
                    'condition'     => [
                        'premium_blog_excerpt'  => 'yes',
                        ]
                    ]
                );
        
        /*Author Meta*/ 
        $this->add_control('premium_blog_author_meta',
                [
                    'label'         => esc_html__('Author Meta', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                    ]
                );
        
         
        /*Date Meta*/ 
        $this->add_control('premium_blog_date_meta',
                [
                    'label'         => esc_html__('Date Meta', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                    ]
                );
        
        /*Categories Meta*/ 
        $this->add_control('premium_blog_categories_meta',
                [
                    'label'         => esc_html__('Categories Meta', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                    ]
                );
        
        /*Comments Meta*/ 
        $this->add_control('premium_blog_comments_meta',
                [
                    'label'         => esc_html__('Comments Meta', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                    ]
                );
        
        /*Tags Meta*/ 
        $this->add_control('premium_blog_tags_meta',
                [
                    'label'         => esc_html__('Tags Meta', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                    ]
                );
        
        /*Paging*/ 
        $this->add_control('premium_blog_paging',
                [
                    'label'         => esc_html__('Paging', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'no',
                    ]
                );
 
        /*Number of Posts*/
		$this->add_control('premium_blog_number_of_posts',
                [
                    'label'         => esc_html__('Posts Per Page', 'premium_elementor'),
                    'type'          => Controls_Manager::NUMBER,
					'min'			=> 1,
					'default'		=> 1,
                    ]
                );
		
		/*Posts Offset*/
		$this->add_control('premium_blog_offset',
			[
				'label' 			=> esc_html__( 'Offset Count', 'boosted-elements-progression' ),
				'type' 				=> Controls_Manager::NUMBER,
                'default' 			=> '0',
				'min' 				=> '0',
			]
		);

        /*Front Text Align*/
        $this->add_responsive_control('premium_flip_text_align',
                [
                    'label'         => esc_html__( 'Text Align', 'elementor' ),
                    'type'          => Controls_Manager::CHOOSE,
                    'options'       => [
                        'left'      => [
                            'title'=> esc_html__( 'Left', 'elementor' ),
                            'icon' => 'fa fa-align-left',
                            ],
                        'center'    => [
                            'title'=> esc_html__( 'Center', 'elementor' ),
                            'icon' => 'fa fa-align-center',
                            ],
                        'right'     => [
                            'title'=> esc_html__( 'Right', 'elementor' ),
                            'icon' => 'fa fa-align-right',
                            ],
                        ],
                    'default'       => 'left',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-content-wrapper' => 'text-align: {{VALUE}};',
                        ],
                    ]
                );

       
        /*End Content Section*/
        $this->end_controls_section();
        
        /*Start Color Style Section*/
        $this->start_controls_section('premium_blog_colors_section',
                [
                    'label'         => esc_html__('Colors', 'premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                    ]
                );
        
        /*Plus Icon Color*/
        $this->add_control('premium_blog_plus_color',
                [
                    'label'         => esc_html__('Plus Icon Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#1c1c1c',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-thumbnail-container:before, {{WRAPPER}} .premium-blog-thumbnail-container:after' => 'background-color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Overlay Color*/
        $this->add_control('premium_blog_overlay_color',
                [
                    'label'         => esc_html__('Overlay Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-framed-effect, {{WRAPPER}} .premium-blog-bordered-effect,{{WRAPPER}} .premium-blog-squares-effect:before,{{WRAPPER}} .premium-blog-squares-effect:after,{{WRAPPER}} .premium-blog-squares-square-container:before,{{WRAPPER}} .premium-blog-squares-square-container:after, {{WRAPPER}} .premium-blog-format-container:hover,{{WRAPPER}} .premium-blog-pagination-container .current' => 'background-color: {{VALUE}};',
                        ]
                    ]
                );
        /*Content Background Color*/
        $this->add_control('premium_blog_content_background_color',
                [
                    'label'         => esc_html__('Content Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#f5f5f5',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-content-wrapper'  => 'background-color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Titles Color*/
        $this->add_control('premium_blog_title_color',
                [
                    'label'         => esc_html__('Post Title Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#1c1c1c',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-entry-title a'  => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Post Format Background Color*/
        $this->add_control('premium_blog_format_back_color',
                [
                    'label'         => esc_html__('Format Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-format-container'  => 'background-color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Post Format Icon Color*/
        $this->add_control('premium_blog_format_icon_color',
                [
                    'label'         => esc_html__('Format Icon Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#1c1c1c',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-format-container i'  => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Post Content Color*/
        $this->add_control('premium_blog_post_content_color',
                [
                    'label'         => esc_html__('Post Content Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#7a7a7a',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-post-content'  => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Meta Color*/
        $this->add_control('premium_blog_meta_color',
                [
                    'label'         => esc_html__('Meta Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#555',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-entry-meta, {{WRAPPER}} .premium-blog-entry-meta a'  => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Meta Color*/
        $this->add_control('premium_blog_tags_color',
                [
                    'label'         => esc_html__('Tags Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#555',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-post-tags-container, {{WRAPPER}} .premium-blog-post-tags-container a'  => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Meta Hover Color*/
        $this->add_control('premium_blog_meta_tags_hover_color',
                [
                    'label'         => esc_html__('Link Hover Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#6ec1e4',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-blog-entry-title a:hover , {{WRAPPER}} .premium-blog-entry-meta a:hover, {{WRAPPER}} .premium-blog-post-tags-container a:hover'  => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        
        /*End Color Style Section*/
        $this->end_controls_section();
       
    }

    protected function render($instance = [])
    {
        
        if ( get_query_var('paged') ) { $paged = get_query_var('paged'); } else if ( get_query_var('page') ) {   $paged = get_query_var('page'); } else {  $paged = 1; }
        
        // get our input from the widget settings.
        $settings = $this->get_settings();
        
        $image_effect = $settings['premium_blog_hover_image_effect'];
        
        $post_effect = $settings['premium_blog_hover_color_effect'];
        
        $offset = $settings['premium_blog_offset'];
        
        $post_per_page = $settings['premium_blog_number_of_posts'];
        
        $new_offset = $offset + ( ( $paged - 1 ) * $post_per_page );
        
        $post_args = premium_blog_get_post_settings($settings);

        $posts = premium_blog_get_post_data($post_args, $paged , $new_offset);
?>
<?php
if(count($posts)){
    global $post;
    ?>
        <?php
        foreach($posts as $post){
            setup_postdata($post);
            ?>
<div class="premium-blog-post-container">
    <div class="premium-blog-thumb-effect-wrapper">
        <div class="premium-blog-thumbnail-container <?php echo 'premium-blog-' . $image_effect . '-effect';?>">
            <?php the_post_thumbnail('full'); ?>
        </div>
        <div class="premium-blog-effect-container <?php echo 'premium-blog-'. $post_effect . '-effect'; ?>">
            <?php if( $settings['premium_blog_hover_color_effect'] === 'bordered' ) : ?>
            <div class="premium-blog-bordered-border-container"></div>
            <?php elseif( $settings['premium_blog_hover_color_effect'] === 'squares' ) : ?>
            <div class="premium-blog-squares-square-container"></div>
            <?php endif; ?>
        </div>
    </div>
    <div class="premium-blog-content-wrapper">
        <div class="premium-blog-inner-container">
            <?php if( $settings['premium_blog_post_format_icon'] === 'yes' ) : ?>
            <div class="premium-blog-format-container">
                <a href="<?php the_permalink(); ?>" title="<?php if( get_post_format() === ' ') : echo 'standard' ; else : echo get_post_format();  endif; ?>" target="_blank"><i class="fa fa-<?php if ( get_post_format() === 'aside' ) : echo 'file-text-o'; ?>
                <?php elseif ( get_post_format() === 'audio' ) :  echo 'music'; ?>
                <?php elseif ( get_post_format() === 'gallery' ) : echo 'file-image-o'; ?>
                <?php elseif ( get_post_format() === 'image' ) : echo 'picture-o'; ?>
                <?php elseif ( get_post_format() === 'link' ) : echo 'link'; ?>
                <?php elseif ( get_post_format() === 'quote' ) :echo 'quote-left';  ?>
                <?php elseif ( get_post_format() === 'video' ) : echo 'video-camera'; ?>
                <?php else : echo 'thumb-tack'; ?>
                <?php endif; ?>"></i></a>
            </div>
            <?php endif; ?>
            <div class="premium-blog-entry-container">
                <h2 class="premium-blog-entry-title"><a href="<?php the_permalink(); ?>" target="_blank"><?php the_title(); ?></a></h2>
                <div class="premium-blog-entry-meta" style="<?php if( $settings['premium_blog_post_format_icon'] !== 'yes' ) : echo 'margin-left:0px'; endif; ?>">
                    <?php if( $settings['premium_blog_author_meta'] === 'yes' ) : ?>
                    <span class="premium-blog-post-author premium-blog-meta-data"><i class="fa fa-user fa-fw"></i><?php the_author_posts_link();?></span>
                    <?php endif; ?>
                    <?php if( $settings['premium_blog_date_meta'] === 'yes' ) : ?>
                    <span class="premium-blog-post-time premium-blog-meta-data"><i class="fa fa-calendar fa-fw"></i><a href="<?php the_permalink(); ?>" target="_blank"><?php the_time('F j, Y'); ?></a></span>
                    <?php endif; ?>
                    <?php if( $settings['premium_blog_categories_meta'] === 'yes' ) : ?>
                    <span class="premium-blog-post-categories premium-blog-meta-data"><i class="fa fa-align-left fa-fw"></i><?php the_category(', '); ?></span>
                    <?php endif; ?>
                    <?php if( $settings['premium_blog_comments_meta'] === 'yes' ) : ?>
                    <span class="premium-blog-post-comments premium-blog-meta-data"><i class="fa fa-comments-o fa-fw"></i><a href="<?php the_permalink(); ?>" target="_blank"><?php comments_number('0 Comments', '1', '%'); ?>  </a></span>
                    <?php endif; ?>
                    <span class="premium-blog-post-edit  premium-blog-meta-data"><i class="fa fa-pencil fa-fw"></i><?php edit_post_link(); ?></span>
                </div>
            </div>
        </div>
        <div class="premium-blog-post-content" style="<?php if ( $settings['premium_blog_post_format_icon'] !== 'yes' ) : echo 'margin-left:0px;'; endif; ?>">
            <?php 
            if ( $settings['premium_blog_excerpt'] === 'yes' ) : 
                echo  premium_addons_get_excerpt_by_id(get_the_ID(),$settings['premium_blog_excerpt_length']);
         else: the_content(); 
         endif; ?>
        </div>
        <div class="premium-blog-post-tags-container" style="<?php if( $settings['premium_blog_post_format_icon'] !== 'yes' ) : echo 'margin-left:0px;'; endif; ?>">
            <?php if( $settings['premium_blog_tags_meta'] === 'yes' && the_tags() != '' ) : ?>
            <span class="premium-blog-post-tags"><i class="fa fa-tags fa-fw"></i><?php the_tags(' ', ', '); ?> </span>
            <?php endif; ?>
        </div>   
    </div>
</div>
    <?php
        }
        ?>
<?php if ( $settings['premium_blog_paging'] === 'yes' ) : ?>
<div class="premium-blog-pagination-container">
            <?php 
            $count_posts = wp_count_posts();
            $published_posts = $count_posts->publish;
            
            $page_tot = ceil( ( $published_posts - $offset ) / $settings['premium_blog_number_of_posts'] );
            if ( $page_tot > 1 ) {
                $big        = 999999999;
                echo paginate_links( array(
                    'base'      => str_replace( $big, '%#%',get_pagenum_link( 999999999, false ) ),
                    'format'    => '?paged=%#%',
                    'current'   => max( 1, $paged ),
                    'total'     => $page_tot,
                    'prev_next' => true,
                    'prev_text' => esc_html__("&lsaquo; Previous"),
                    'next_text' => esc_html__("Next &rsaquo;"),
                    'end_size'  => 1,
                    'mid_size'  => 2,
                    'type'      => 'list'
                    )
                        );
            }
            ?>
</div>
<?php endif; ?>
<?php 
    wp_reset_postdata();
    
} ?>



    <?php
    }
}
Plugin::instance()->widgets_manager->register_widget_type(new Premium_Blog_Widget());
