<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Premium_Modal_Box_Widget extends Widget_Base
{
    protected $templateInstance;

    public function getTemplateInstance() {
        return $this->templateInstance = premium_Template_Tags::getInstance();
    }

    public function get_name() {
        return 'premium-addon-modal-box';
    }

    public function get_title() {
        return esc_html__('Premium Modal Box', 'premium_elementor');
    }

    public function get_icon() {
        return 'pa-pa-spin';
    }

    public function get_categories() {
        return [ 'premium-elements' ];
    }


    // Adding the controls fields for the premium modal box
    // This will controls the animation, colors and background, dimensions etc
    protected function _register_controls() {

        /* Start Box Content Section */
        
        $this->start_controls_section('premium_modal_box_selector_content_section', 
                [
                    'label'         => esc_html__('Selector Content', 'premium_elementor'),
                ]
                );
        
        /*Modal Box Display On*/
        $this->add_control('premium_modal_box_display_on',
                [
                    'label'         => esc_html__('Display Modal On', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'options'       => [
                        'button'  => esc_html('Button','premium-elementor'),
                        'image'   => esc_html('Image','premium-elementor'),
                        'text'    => esc_html('Text','premium-elementor'),
                        'pageload'=> esc_html('On Page Load','premium-elementor'),
                    ],
                    'label_block'   =>  true,
                    'default'       => 'button',  
                ]
                );
      
        /*Button Size*/
        $this->add_control('premium_modal_box_button_size',
                [
                    'label'         => esc_html__('Button Size', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'options'       => [
                        'sm'    => esc_html('Small','premium-elementor'),
                        'md'    => esc_html('Medium','premium-elementor'),
                        'lg'    => esc_html('Large','premium-elementor'),
                        'block' => esc_html('Block','premium-elementor'),
                    ],
                    'label_block'   => true,
                    'default'       => 'sm',
                    'condition'     => [
                      'premium_modal_box_display_on'  => 'button'
                    ],
                ]
                );
        
        /*Button Text*/ 
        $this->add_control('premium_modal_box_button_text',
                [
                    'label'         => esc_html__('Button Text', 'premium_elementor'),
                    'default'       => 'Open Modal',
                    'type'          => Controls_Manager::TEXT,
                    'label_block'   => true,
                    'condition'     => [
                      'premium_modal_box_display_on'  => 'button'
                    ],
                ]
                );
        
        /*Image Source*/ 
        $this->add_control('premium_modal_box_image_src',
                [
                    'label'         => esc_html__('Choose Image', 'premium_elementor'),
                    'type'          => Controls_Manager::MEDIA,
                    'default'       => [
                        'url'   => Utils::get_placeholder_image_src(),
                    ],
                    'condition'     => [
                        'premium_modal_box_display_on'    => 'image',
                    ],
                    'label_block'   => true,
                ]
                );
        
        /*Text Selector*/
        $this->add_control('premium_modal_box_selector_text',
                [
                    'label'         => esc_html__('Enter Text', 'premium_elementor'),
                    'type'          => Controls_Manager::TEXT,
                    'label_block'   => true,
                    'default'       => esc_html__('Open Modal', 'premium_elementor'),
                    'condition'     => [
                        'premium_modal_box_display_on'  => 'text',
                    ]
                ]
                );
        
        /*On Load Trigger Delay*/
        $this->add_control('premium_modal_box_popup_delay',
                [
                    'label'         => esc_html__('Delay in Popup Display','premium_elementor'),
                    'type'          => Controls_Manager::NUMBER,
                    'default'       => 1,
                    'label_block'   => true,
                    'condition'     => [
                        'premium_modal_box_display_on'  => 'pageload',
                    ]
                ]
                );
        
        /*Alignment*/
        $this->add_responsive_control('premium_modal_box_selector_align',
                [
                    'label' => __( 'Selector Alignment', 'premium_elementor' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                            'left'    => [
                                    'title' => __( 'Left', 'premium_elementor' ),
                                    'icon' => 'fa fa-align-left',
                            ],
                            'center' => [
                                    'title' => __( 'Center', 'premium_elementor' ),
                                    'icon' => 'fa fa-align-center',
                            ],
                            'right' => [
                                    'title' => __( 'Right', 'premium_elementor' ),
                                    'icon' => 'fa fa-align-right',
                            ],
                        ],
                    'default'       => 'center',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-selector-container' => 'text-align: {{VALUE}};',
                        ],
                    'default' => '',
                ]
		);

        
        $this->end_controls_section();
        
        $this->start_controls_section('premium_modal_box_content_section',
                [
                    'label'         => esc_html__('Box Content', 'premium_elementor'),
                    ]
                );
        
        /*Icon To Display*/
        $this->add_control('premium_modal_box_icon_selection',
                [
                    'label'         => esc_html__('Icon to Display', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'options'       => [
                        'noicon'  => esc_html('No Icon'),
                        'fonticon'=> esc_html('Font Awesome Icon'),
                        'image'   => esc_html('Custom Image Icon'),
                    ],
                    'default'       => 'noicon',
                    'label_block'   => true
                ]
                );
        
        /*Font Awesome Icon*/
        $this->add_control('premium_modal_box_font_icon', 
                [
                    'label'         => esc_html__('Font Awesome Icon', 'premium_elementor'),
                    'type'          => Controls_Manager::ICON,
                    'condition'     => [
                        'premium_modal_box_icon_selection'    => 'fonticon',
                    ],
                    'label_block'   => true,
                ]
                );
        
        /*Image Icon*/ 
        $this->add_control('premium_modal_box_image_icon',
                [
                    'label'         => esc_html__('Custom Image Icon', 'premium_elementor'),
                    'type'          => Controls_Manager::MEDIA,
                    'default'       => [
                        'url'   => Utils::get_placeholder_image_src(),
                    ],
                    'condition'     => [
                        'premium_modal_box_icon_selection'    => 'image',
                    ],
                    'label_block'   => true,
                ]
                );

        /*Modal Box Title*/ 
        $this->add_control('premium_modal_box_title',
                [
                    'label'         => esc_html__('Modal Box Title', 'premium_elementor'),
                    'default'       => 'Modal Box Title',
                    'type'          => Controls_Manager::TEXT,
                    'label_block'   => true,
                ]
                );
        
        /*Modal Box Content*/
        $this->add_control('premium_modal_box_content',
                [
                    'label'         => esc_html__('Modal Box Content', 'premium_elementoror'),
                    'type'          => Controls_Manager::WYSIWYG,
                    'default'       => 'Modal Box Content',
                    'selector'      => '{{WRAPPER}} .premium-modal-box-modal-body',
                ]
                );
        
        /*Modal Size*/
        $this->add_control('premium_modal_box_modal_size',
                [
                    'label'         => esc_html__('Modal Width', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'range'         => [
                        'px'    => [
                            'min'   => 50,
                            'max'   => 1000,
                        ]
                    ],
                    'label_block'   => true,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-modal-dialog' => 'width: {{SIZE}}{{UNIT}};',
                    ]
                ]
                );
        
        /*Content Box Border*/
        $this->add_group_control(
            Group_Control_Border::get_type(),
                [
                    'name'          => 'contentborder',
                    'selector'      => '{{WRAPPER}} .premium-modal-box-modal-content',
                ]
                );
        
        /*Border Radius*/
        $this->add_control('premium_modal_box_border_radius',
                [
                   'label'          => esc_html__('Border Radius', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-modal-content'     => 'border-radius: {{SIZE}}{{UNIT}};',
                    ]
                ]
                );

        /*Upper Close Button*/
        $this->add_control('premium_modal_box_upper_close',
                [
                    'label'         => esc_html__('Upper Close Button', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                ]
                );
        
        /*Lower Close Button*/
        $this->add_control('premium_modal_box_lower_close',
                [
                    'label'         => esc_html__('Lower Close Button', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                ]
                );
        
        /*End Box Content Section*/
        $this->end_controls_section();
        
        /*Start Styling Section*/
        
        /*Selector Style*/
        $this->start_controls_section('premium_modal_box_selector_style_section',
                [
                    'label'         => esc_html__('Selector Style', 'premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                ]
                );
        
        $this->start_controls_tabs('premium_modal_box_button_style');
        
        /*Button Color*/
        $this->start_controls_tab('premium_modal_box_tab_button_normal',
                [
                    'label'         => esc_html__( 'Normal', 'premium_elementor' ),
                    'condition'     => [
                        'premium_modal_box_display_on'  => 'button',
                        ]
                    ]
		);
        
        /*Button Background Color*/
        $this->add_control('premium_modal_box_button_background',
                [
                    'label'         => esc_html__('Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-selector-container .btn-info' => 'background:{{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_modal_box_display_on'  => 'button',
                        ]
                    ]
                );
        
        /*Button Background Color*/
        $this->add_control('premium_modal_box_button_text_background',
                [
                    'label'         => esc_html__('Text Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'default'       => '#fff',
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-selector-container .btn-info' => 'color:{{VALUE}};',
                        ],
                    'condition'     => [
                        'premium_modal_box_display_on'  => 'button',
                        ]
                    ]
                );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab('premium_modal_box_tab_button_hover',
                [
                    'label'         => esc_html__('Hover', 'premium_elementor'),
                    'condition'     => [
                        'premium_modal_box_display_on'  => 'button',
                        ]
                ]
                );
        
        /*Button Hover Background Color*/
        $this->add_control('premium_modal_box_button_hover_background',
                [
                    'label'         => esc_html__('Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-selector-container .btn-info:hover' => 'background: {{VALUE}};',
                        ],
                    ]
                );

        /*Button Background Color*/
        $this->add_control('premium_modal_box_button_text_hover_background',
                [
                    'label'         => esc_html__('Text Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-selector-container .btn-info:hover' => 'color: {{VALUE}};',
                        ],
                    ]
                );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        /*Button Border*/
        $this->add_group_control(
            Group_Control_Border::get_type(), 
                [
                    'name'          => 'button_border',
                    'selector'      => '{{WRAPPER}} .premium-modal-box-button-selector ',
                    'condition'     => [
                        'premium_modal_box_display_on' => 'button'
                    ]
                ]
                );
        
        /*Button Border Radius*/
        $this->add_control('premium_modal_box_button_border_radius',
                [
                   'label'          => esc_html__('Border Radius', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-button-selector '     => 'border-radius:{{SIZE}}{{UNIT}};',
                    ],
                    'condition'     => [
                        'premium_modal_box_display_on' => 'button'
                    ]
                ]
                );
        
        /*Image Border*/
        $this->add_group_control(
            Group_Control_Border::get_type(), 
                [
                    'name'          => 'imageborder',
                    'selector'      => '{{WRAPPER}} .premium-modal-box-img-selector',
                    'condition'     => [
                        'premium_modal_box_display_on' => 'image'
                    ]
                ]
                );
        
        /*Image Border Radius*/
        $this->add_control('premium_modal_box_image_border_radius',
                [
                   'label'          => esc_html__('Border Radius', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-img-selector '     => 'border-radius:{{SIZE}}{{UNIT}};',
                    ],
                    'condition'     => [
                        'premium_modal_box_display_on' => 'image'
                    ]
                ]
                );
                
        $this->end_controls_section();
        
        /*Modal Box Style*/
        $this->start_controls_section('premium_modal_box_general_settings',
                [
                    'label'         => esc_html__('Modal Box Style', 'premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                    ]
                );
        
        /*Modal Margin Top*/
        $this->add_control('premium_modal_box_margin_top',
                [
                    'label'         => esc_html__('Margin Top','premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%' , 'em'],
                    'selectors'      => [
                        '{{WRAPPER}} .premium-modal-box-modal-dialog'   => 'margin-top: {{SIZE}}{{UNIT}};',
                    ]
                ]
                );
        
        /*Modal Margin Bottom*/
        $this->add_control('premium_modal_box_margin_bottom',
                [
                    'label'         => esc_html__('Margin Bottom', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'      => [
                        '{{WRAPPER}} .premium-modal-box-modal-dialog'   => 'margin-bottom: {{SIZE}}{{UNIT}};',
                    ]
                ]
                );
        
        /*Modal Background Color*/
        $this->add_control('premium_modal_box_modal_background',
                [
                    'label'         => esc_html__('Modal Box Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-modal'  => 'background:{{VALUE}};',
                        ]
                    ]
                );
        
        /*Header Background Color*/
        $this->add_control('premium_modal_box_header_background',
                [
                    'label'         => esc_html__('Header Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-modal-header'  => 'background: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Content Background Color*/
        $this->add_control('premium_modal_box_content_background',
                [
                    'label'         => esc_html__('Content Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-modal-body'  => 'background: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Footer Background Color*/
        $this->add_control('premium_modal_box_footer_background',
                [
                    'label'         => esc_html__('Footer Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-modal-footer'  => 'background: {{VALUE}};',
                        ]
                    ]
                );
        
        /*End General Settings Section*/
        $this->end_controls_section();
        
        /*Start Header Seettings Section*/
        $this->start_controls_section('premium_modal_box_header_settings',
                [
                    'label'         => esc_html__('Header Text Settings', 'premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                    ]
                );
        
        /*Header Text Color*/
        $this->add_control('premium_modal_box_header_text_color',
                [
                    'label'         => esc_html__('Text Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .premium-modal-box-modal-title' => 'color: {{VALUE}};',
                    ]
                ]
                );
        
        /*Header Text Typography*/
        $this->add_group_control(
            Group_Control_Typography::get_type(),
                [
                    'name'          => 'headertext',
                    'label'         => esc_html__('Typography', 'premium_elementor'),
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-modal-box-modal-title',
                ]
                );
        
        /*End Header Settings Section*/
        $this->end_controls_section();
        
        /*Start Close Button Section*/
        $this->start_controls_section('premium_modal_box_upper_close_button_section',
                [
                    'label'         => esc_html__('Upper Close Button Settings', 'premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                    'condition'     => [
                        'premium_modal_box_upper_close'   => 'yes',
                    ]
                ]
                );
        
        /*Close Button Size*/
        $this->add_control('premium_modal_box_upper_close_button_size',
                [
                    'label'         => esc_html__('Button Size', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%' ,'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-modal-header button' => 'font-size: {{SIZE}}{{UNIT}};',
                    ]
                ]
                );
        
        /*Close Button Background Color*/
        $this->add_control('premium_modal_box_upper_close_button_background_color',
                [
                    'label'         => esc_html__('Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-close-button-container' => 'background:{{VALUE}};',
                    ]
                ]
                );

        /*End Upper Close Button Style Section*/
        $this->end_controls_section();
        
        /*Start Close Button Section*/
        $this->start_controls_section('premium_modal_box_lower_close_button_section',
                [
                    'label'         => esc_html__('Lower Close Button Settings', 'premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                    'condition'     => [
                        'premium_modal_box_upper_close'   => 'yes',
                    ]
                ]
                );
        
        /*Close Button Size*/
        $this->add_control('premium_modal_box_lower_close_button_width',
                [
                    'label'         => esc_html__('Button Width (PX)', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-modal-lower-close' => 'min-width: {{SIZE}}{{UNIT}};',
                    ]
                ]
                );
        
        /*Close Button Background Color*/
        $this->add_control('premium_modal_box_lower_close_button_background_color',
                [
                    'label'         => esc_html__('Background Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-modal-box-modal-lower-close' => 'background: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Close Button Text Typography*/
        $this->add_group_control(
            Group_Control_Typography::get_type(),
                [
                    'name'          => 'lowerclose',
                    'label'         => esc_html__('Typography', 'premium_elementor'),
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-modal-box-modal-lower-close',
                ]
                );

        /*End Lower Close Button Style Section*/
        $this->end_controls_section();
        
    }

    protected function render($instance = [])
    {
        // get our input from the widget settings.
        $settings = $this->get_settings();
?>
    
<div class="container premium-modal-box-container">
  <!-- Trigger The Modal Box -->
  <div class="premium-modal-box-selector-container">
      <?php
      if ( $settings['premium_modal_box_display_on'] === 'button' ) : ?>
      <button type="button" class="premium-modal-box-button-selector btn btn-info <?php
      if( $settings['premium_modal_box_button_size'] === 'sm' ) : echo "btn-sm";
      elseif( $settings['premium_modal_box_button_size'] === 'md' ) : echo "btn-md";
      elseif( $settings['premium_modal_box_button_size'] === 'lg' ) : echo "btn-lg";
      elseif( $settings['premium_modal_box_button_size'] === 'block' ) : echo "btn-block"; endif; ?>" data-toggle="modal" data-target="#myModal-<?php echo esc_attr( $this->get_id() ); ?>"><?php echo $settings['premium_modal_box_button_text']; ?></button>
      <?php elseif ( $settings['premium_modal_box_display_on'] === 'image' ) : ?>
      <img class="premium-modal-box-img-selector" data-toggle="modal" data-target="#myModal-<?php  echo esc_attr( $this->get_id() ); ?>" src="<?php echo $settings['premium_modal_box_image_src']['url'];?>">
      <?php elseif($settings['premium_modal_box_display_on'] === 'text') : ?>
      <span class="premium-modal-box-text-selector" data-toggle="modal" data-target="#myModal-<?php  echo esc_attr( $this->get_id() ); ?>"><?php echo $settings['premium_modal_box_selector_text'];?></span>
      <?php elseif ( $settings['premium_modal_box_display_on'] === 'pageload' ) : ?>
          <script>
              jQuery( document ).ready( function( $ ){
                  setTimeout( function(){
                      $( "#myModal-<?php  echo esc_attr( $this->get_id() ); ?>" ).modal();
                  },<?php echo $settings['premium_modal_box_popup_delay'] * 1000; ?>);
              });
          </script>
       <?php endif; ?>
  </div>
  
  
  <!-- Modal -->
  <div class="modal fade premium-modal-box-modal" id="myModal-<?php echo  $this->get_id(); ?>" role="dialog">
    <div class="modal-dialog premium-modal-box-modal-dialog">
    
      <!-- Modal content-->
      <div class="modal-content premium-modal-box-modal-content">
        <div class="modal-header premium-modal-box-modal-header">
            <?php if ( $settings['premium_modal_box_upper_close'] === 'yes' ) : ?>
            <div class="premium-modal-box-close-button-container">
                <button type="button" class="close premium-modal-box-modal-close" data-dismiss="modal">&times;</button>
            </div>
            <?php endif; ?>
            <h3 class="modal-title premium-modal-box-modal-title">
                <?php if($settings['premium_modal_box_icon_selection'] === 'fonticon') : ?>
                <i class="fa <?php echo $settings['premium_modal_box_font_icon'];?>"></i>
                    <?php elseif( $settings['premium_modal_box_icon_selection'] === 'image' ) : ?>
                <img src="<?php echo $settings['premium_modal_box_image_icon']['url'];?>">
                    <?php endif; ?><?php echo $settings['premium_modal_box_title'];?></h3>
        </div>
          <div class="modal-body premium-modal-box-modal-body">
              <?php echo $settings['premium_modal_box_content'];?>
          </div>
          <?php if ( $settings['premium_modal_box_lower_close'] === 'yes' ) : ?>
          <div class="modal-footer premium-modal-box-modal-footer">
              <button type="button" class="btn btn-default premium-modal-box-modal-lower-close" data-dismiss="modal">Close
              </button>
          </div>
          <?php endif; ?>
      </div>
    </div>
  </div>
</div>

    <?php
    }
}
Plugin::instance()->widgets_manager->register_widget_type(new Premium_Modal_Box_Widget());
