<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class Premium_Video_Box_Widget extends Widget_Base
{
    protected $templateInstance;

    public function getTemplateInstance() {
        return $this->templateInstance = premium_Template_Tags::getInstance();
    }

    public function get_name() {
        return 'premium-addon-video-box';
    }

    public function get_title() {
        return esc_html__('Premium Video Box', 'premium_elementor');
    }

    public function get_icon() {
        return 'pa-pa-video';
    }

    public function get_categories() {
        return [ 'premium-elements' ];
    }

    // Adding the controls fields for the premium video box
    // This will controls the animation, colors and background, dimensions etc
    protected function _register_controls() {

        /* Start Image Settings Section */
        $this->start_controls_section('premium_video_box_image_settings',
                [
                    'label'         => esc_html__('Image Settings', 'premium_elementor'),
                ]
                );
        
        /*Video Box Image*/ 
        $this->add_control('premium_video_box_image',
                [
                    'label'         => esc_html__('Image', 'premium_elementor'),
                    'description'   => esc_html__('Choose the video box Image', 'premium_elementor' ),
                    'type'          => Controls_Manager::MEDIA,
                    'default'       => [
                        'url'	=> Utils::get_placeholder_image_src()
                ],
                    'label_block'   => true,
                ]
                );
        
        /*Image Border*/
        $this->add_group_control(
            Group_Control_Border::get_type(),
                [
                    'name'          => 'image_border',        
                    'selector'      => '{{WRAPPER}} .premium-video-box-image, {{WRAPPER}} .premium-video-box-video-container iframe',
                ]
                );
        
        /*Image Border Radius*/
        $this->add_control('premium_video_box_image_border_radius', 
                [
                    'label'         => esc_html__('Border Radius', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-video-box-image, {{WRAPPER}} .premium-video-box-video-container iframe'  => 'border-radius: {{SIZE}}{{UNIT}};',
                        ]
                    ]
                );
        
        /*End Image Settings Section*/
        $this->end_controls_section();
        
        /*Start Play Icon Settings*/
        $this->start_controls_section('premium_video_box_play_icon_settings', 
                [
                    'label'         => esc_html__('Play Icon Settings', 'premium_elementor'),
                ]
                );

        /*Play Icon Size*/
        $this->add_control('premium_video_box_play_icon_size',
                [
                    'label'         => esc_html__('Icon Size', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-video-box-play-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                        ]
                    ]
                );
        
        /*Play Icon Color*/
        $this->add_control('premium_video_box_play_icon_color', 
                [
                    'label'         => esc_html__('Icon Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-video-box-play-icon'  => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Play Icon Background Color*/
        $this->add_group_control(
            Group_Control_Background::get_type(),
                [
                    'name'              => 'premium_video_box_play_icon_background_color',
                    'types'             => ['classic', 'gradient'],
                    'selector'          => '{{WRAPPER}} .premium-video-box-play-icon-container',
                ]
                );
        
        /*Play Icon Border*/
        $this->add_group_control(
            Group_Control_Border::get_type(),
                [
                    'name'          => 'icon_border',        
                    'selector'      => '{{WRAPPER}} .premium-video-box-play-icon-container',
                ]
                );
        
        /*Play Icon Border Radius*/
        $this->add_control('premium_video_box_icon_border_radius', 
                [
                    'label'         => esc_html__('Border Radius', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'size_units'    => ['px', '%', 'em'],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-video-box-play-icon-container'  => 'border-radius: {{SIZE}}{{UNIT}};',
                        ]
                    ]
                );
        
        /*Enable Icon Hover Size Change*/
        $this->add_control('premium_video_box_icon_hover_animation',
                [
                    'label'         => esc_html__('Hover Animation', 'premium_elementor'),
                    'type'          => Controls_Manager::SWITCHER,
                    'default'       => 'yes',
                ]
                );
        
        /*End Play Icon Settings*/
        $this->end_controls_section();
        
        /*Start Description Text Section*/
        $this->start_controls_section('premium_video_box_description_text_section', 
                [
                    'label'         => esc_html__('Video Description Settings', 'premium_elementor'),
                ]
                );
        
        /*Description Text*/
        $this->add_control('premium_video_box_description_text', 
                [
                    'label'         => esc_html__('Description Text', 'premium_elementor'),
                    'type'          => Controls_Manager::TEXTAREA,
                    'label_block'   => true,
                ]
                );
        
        /*Description Top Position*/
        $this->add_control('premium_video_box_description_position', 
                [
                    'label'         => esc_html__('Description Top Position (%)', 'premium_elementor'),
                    'type'          => Controls_Manager::SLIDER,
                    'label_block'   => true,
                    'default'       => [
                        'size' => 50,
                        ],
                    'selectors'     => [
                        '{{WRAPPER}} .premium-video-box-description-container' => 'top: {{SIZE}}%;',
                        ]
                    ]
                );
        
        /*End Description Text Section*/
        $this->end_controls_section();
        
        /*Start Video Settings Section*/
        $this->start_controls_section('premium_video_box_video_settings_section', 
                [
                    'label'         => esc_html__('Video Settings', 'premium_elementor'),
                ]
                );
        
        /*Video Type*/
        $this->add_control('premium_video_box_video_type',
                [
                    'label'         => esc_html__('Video Type', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'default'       => 'youtube',
                    'options'       => [
                        'youtube'       => esc_html__('Youtube', 'premium_elementor'),
                        'vimeo'         => esc_html__('Vimeo', 'premium_elementor'),
                        ]
                    ]
                );
        
        /*Video Id or Link*/
        $this->add_control('premium_video_box_video_id_embed_selection',
                [
                    'label'         => esc_html__('Id/Embded URL', 'premium_elementor'),
                    'type'          => Controls_Manager::SELECT,
                    'default'       => 'id',
                    'options'       => [
                        'id'    => esc_html__('Id', 'premium_elementor'),
                        'embed' => esc_html__('Embed URL', 'premium_elementor'),
                        ]
                    ]
                );
        
        /*Video Id*/
        $this->add_control('premium_video_box_video_id', 
                [
                    'label'         => esc_html__('Video Id', 'premium_elementor'),
                    'description'   => esc_html__('for example: z1hQgVpfTKU', 'premium_elementor'),
                    'type'          => Controls_Manager::TEXT,
                    'condition'     => [
                        'premium_video_box_video_id_embed_selection' => 'id',
                        ]
                    ]
                );
        
        /*Video Link*/
        $this->add_control('premium_video_box_video_embed', 
                [
                    'label'         => esc_html__('Embed Video src', 'premium_elementor'),
                    'description'   => esc_html__('for example: https://www.youtube.com/embed/z1hQgVpfTKU', 'premium_elementor'),
                    'type'          => Controls_Manager::TEXT,
                    'condition'     => [
                        'premium_video_box_video_id_embed_selection' => 'embed',
                        ]
                    ]
                );
        
        /*End Video Settings Section*/
        $this->end_controls_section();
        
        /*Start Text Below Icon Style Section*/
        $this->start_controls_section('premium_video_box_text_style_section', 
                [
                    'label'         => esc_html__('Video Box Style','premium_elementor'),
                    'tab'           => Controls_Manager::TAB_STYLE,
                ]
                );
        /*Box Text Shadow*/
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
                [
                    'name'          => 'box_shadow',
                    'selector'      => '{{WRAPPER}} .premium-video-box-container',
                ]
                );
        
        /*Text Color*/
        $this->add_control('premium_video_box_text_color',
                [
                    'label'         => esc_html__('Text Color', 'premium_elementor'),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [
                        '{{WRAPPER}} .premium-video-box-text'   => 'color: {{VALUE}};',
                        ]
                    ]
                );
        
        /*Text Typography*/
        $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'          => 'text_typography',
                    'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
                    'selector'      => '{{WRAPPER}} .premium-video-box-text',
                    ]
                );
        
        /*End Text Below Icon Style Section*/
        $this->end_controls_section();
       
    }

    protected function render($instance = [])
    {
        // get our input from the widget settings.
        $settings = $this->get_settings();
        
        $video_type = $settings['premium_video_box_video_type'];
        
        $video_url_type = $settings['premium_video_box_video_id_embed_selection'];
        
        $video_id = $settings['premium_video_box_video_id'];
        
        $video_embed = $settings['premium_video_box_video_embed'];
?>

<div class="premium-video-box-container" id="premium-video-box-container-<?php echo esc_attr( $this->get_id() ); ?>">
    <div class="premium-video-box-image-container">
        <img class="premium-video-box-image" src="<?php echo $settings['premium_video_box_image']['url']; ?>">
    </div>
    <div class="premium-video-box-play-icon-container">
        <i class="premium-video-box-play-icon fa fa-play fa-lg"<?php if ( $settings['premium_video_box_icon_hover_animation'] === 'yes' ) : ?> onMouseOver="this.style.padding='18px'" onMouseOut="this.style.padding='15px'" <?php endif; ?>>
        </i>
    </div>
    <?php if( !empty( $settings['premium_video_box_description_text'] ) ) : ?>
    <div class="premium-video-box-description-container">
        <p class="premium-video-box-text"><?php echo $settings['premium_video_box_description_text']; ?></p>
    </div>
    <?php endif; ?>
    <div class="premium-video-box-video-container">
        <?php if ( $video_type  === 'youtube'){ ?>
        <?php if ( $video_url_type === 'id' && !empty( $video_id ) ) : ?>
            <iframe src="https://www.youtube.com/embed/<?php echo $video_id; ?>" frameborder="0" gesture="media" allow="encrypted-media" allowfullscreen>
            </iframe>
        <?php elseif ( $video_url_type === 'embed' && !empty( $video_embed ) ) : ?>
            <iframe src="<?php echo $video_embed; ?>" frameborder="0" gesture="media" allow="encrypted-media" allowfullscreen>
            </iframe>
        <?php endif; ?>
        <?php } elseif ( $video_type  === 'vimeo'){ ?>
        <?php if ( $video_url_type === 'id' && !empty( $video_id ) ) : ?>
            <iframe src="https://player.vimeo.com/video/<?php echo $video_id; ?>"  frameborder="0" title="Medicine" webkitallowfullscreen="" mozallowfullscreen="" allowfullscreen="" class="fluidvids-item" data-fluidvids="loaded">
            </iframe>
        <?php elseif ( $video_url_type  === 'embed' && !empty( $video_embed ) ) : ?>
            <iframe src="<?php echo $video_embed; ?>?byline=0&portrait=0" frameborder="0" top="0"  webkitallowfullscreen mozallowfullscreen allowfullscreen>
            </iframe>
        <?php endif; ?>
        <?php } ?>
        
    </div>
</div>
<script>
    jQuery(function( $ ){
       $( "#premium-video-box-container-<?php echo esc_attr( $this->get_id() ); ?>" ).on( "click", function(){
        $( this ).children( ".premium-video-box-video-container" ).css(
        {
            'opacity': '1',
            'visibility': 'visible'
        } );
    } ) 
    });;
</script>

    <?php
    }
}
Plugin::instance()->widgets_manager->register_widget_type(new Premium_Video_Box_Widget());


    
